@@ -13,7 +13,7 @@ read.track.stats <- function(filename, mnemonics = NULL,
                                sd = "numeric"))
 {
   stats <- read.delim(filename, colClasses = colClasses)
-  if (!all(names(stats) == COLNAMES)) {
+  if (!all(COLNAMES %in% names(stats))) {
     stop("Unrecognized track statistic file format")
   }
   stats$label <- relevel.mnemonics(stats$label, mnemonics)
@@ -37,7 +37,7 @@ read.gmtk.track.stats <- function(filename, mnemonics = NULL,
 
 merge.gmtk.track.stats <- function(means, covars) {
   if (!all(means$trackname[1:nrow(covars)] == covars$trackname)) {
-    stop("Track ordering different between means and covars!")
+    stop("Track ordering different between means and covars.")
   } else {
     ## Implicit replication across all segs and subsegs
     stats <- subset(means, select=-value)
@@ -254,12 +254,12 @@ covar2sd <- function(stats) {
 
 normalize.track.stats <- function(stats, cov = FALSE, sd.scale = TRUE) {
   if (!is.array(stats)) {
-    stop("normalize.track.stats expected stats in array format!")
+    stop("normalize.track.stats expected stats in array format.")
   }
 
   ## Normalize mean
   means <- stats[, , "mean"]
-  means.range <- t(apply(means, 1, range))
+  means.range <- t(apply(means, 1, range, finite = TRUE))
   means.min <- means.range[, 1]
   means.max <- means.range[, 2]
   stats[, , "mean"] <- (means - means.min) / (means.max - means.min)
@@ -267,7 +267,7 @@ normalize.track.stats <- function(stats, cov = FALSE, sd.scale = TRUE) {
   if ("sd" %in% dimnames(stats)[[3]]) {
     sds <- stats[, , "sd"]
     if (cov) {  # Make sd into coefficient of variation (capped at 1)
-      sds <- sds / rowMeans(means)
+      sds <- sds / rowMeans(means, na.rm = TRUE)
       sds[sds > 1] <- 1
     } else {  # Normalize same as mean
       sds <- sds / (means.max - means.min)
@@ -284,16 +284,16 @@ normalize.track.stats <- function(stats, cov = FALSE, sd.scale = TRUE) {
 
 normalize.binary.track.stats <- function(stats, cov = FALSE) {
   if (!is.array(stats)) {
-    stop("normalize.binary.track.stats expected stats in array format!")
+    stop("normalize.binary.track.stats expected stats in array format.")
   }
   if (! "sd" %in% dimnames(stats)[[3]]) {
-    stop("normalize.binary.track.stats expected standard deviations!")
+    stop("normalize.binary.track.stats expected standard deviations.")
   }
   ## Compute normalization statistic
   means <- stats[, , "mean"]
   sds <- stats[, , "sd"]
   if (dim(means)[2] != 2) {
-    stop("normalize.binary.track.stats expected 2-label segmentation results!")
+    stop("normalize.binary.track.stats expected 2-label segmentation results.")
   }
 
   means.diff <- apply(means, 1, diff)
@@ -507,22 +507,37 @@ levelplot.track.stats <-
   sds <- stats.norm[, , "sd"]
 
   if (!any(is.finite(means))) {
-    warning("No finite mean values found. Nothing to plot!")
+    warning("No finite mean values found. Nothing to plot.")
     return(NULL)
   } else if (!any(is.finite(sds))) {
     ## Pretent no sds were specified
+    warning("No finite sds values found. Not plotting sd bars.")
     sds <- NULL
   }
 
-  mask.rows <- apply(!is.finite(means), 1, any)  # Any row with an NaN
-  if (any(mask.rows)) {
-    warning("Found infinite or NaN mean values. Ignoring those signal tracks")
-    means <- means[!mask.rows,]
-    sds <- sds[!mask.rows,]
+  keep.rows <- apply(is.finite(means), 1, sum) > 1
+  if (any(!keep.rows)) {
+    warning("Ignoring tracks without at least two finite mean values.")
+    means <- means[keep.rows,]
+    sds <- sds[keep.rows,]
   }
-
+  keep.cols <- apply(is.finite(means), 2, sum) > 0
+  if (any(!keep.cols)) {
+    warning("Ignoring labels without any finite mean values")
+    means <- means[,keep.cols]
+    sds <- sds[,keep.cols]
+  }
+  if (!is.matrix(means)) {
+    stop("After removing non-finite values, there was not enough data to plot.")
+  }
+  if (any(!is.finite(means))) {
+    warning("Cells with missing mean values are being set to mean and sd of 0")
+    means[!is.finite(means)] <- 0
+    sds[!is.finite(means)] <- 0
+  }
+  
   if (threshold || is.null(sds) || sd.shape == "line") {
-    z.range <- range(means, na.rm = TRUE)
+    z.range <- range(means, finite = TRUE)
   } else {
     z.range <- c(min(means, means - sds), max(means + sds))
   }
@@ -553,7 +568,7 @@ levelplot.track.stats <-
     col.ord <- match(label_order, colnames(means))
     stopifnot(col.ord > 0, length(col.ord) == ncol(means))
   }
-  par(oma = c(1, 1, 1, 1))  # Add a margin
+  #par(oma = c(1, 1, 1, 1))  # Add a margin
 
   sds.ordered = NULL
   if (! is.null(sds)) {
@@ -613,7 +628,17 @@ save.track.stats <- function(dirpath, namebase, filename,
                              symmetric = FALSE,
                              clobber = FALSE,
                              square.size = 15,  # px
+                             width = 450 + square.size * nlabels,
+                             height = 200 + square.size * ntracks,
+                             width.pdf = width / 72,
+                             height.pdf = height / 72,
                              ...) {
+  square.size <- as.numeric(square.size)
+  width <- as.integer(width)
+  height <- as.integer(height)
+  width.pdf <- as.numeric(width.pdf)
+  height.pdf <- as.numeric(height.pdf)
+  
   mnemonics <- read.mnemonics(mnemonic_file)
   translations <- read.mnemonics(translation_file)
   res <- load.track.stats(filename,
@@ -623,13 +648,13 @@ save.track.stats <- function(dirpath, namebase, filename,
 
   ntracks <- nlevels(res$stats$trackname)
   nlabels <- nlevels(res$stats$label)
-  height <- 200 + square.size * ntracks
-  width <- 450 + square.size * nlabels
-
+  
   save.images(dirpath, namebase,
               levelplot.track.stats(res, symmetric = symmetric, ...),
               height = height,
               width = width,
+              height.pdf = height.pdf,
+              width.pdf = width.pdf,
               clobber = clobber)
 }
 
