@@ -7,22 +7,22 @@ and have it load much faster in the future.
 INFILE will be parsed to create a special binary file with
 a name of the form: "INFILE.pkl" or "OUTFILE.pkl".
 Then, you can substitute this
-new file for the corresponding SEGMENTATION or ANNOTATIONS
+new file for the corresponding SEGMENTATION or ANNOTATION
 argument in future Segtools calls and Segtools will parse
 it in much faster (but be sure to keep the ".pkl" extension intact)!
 """
 
 from __future__ import division, with_statement
 
-__version__ = "$Revision: 322 $"
+__version__ = "$Revision: 339 $"
 
 import sys
 
-from . import Annotations, Segmentation
+from . import Annotation, Segmentation, add_common_options
 
 def preprocess(infilename, outfilename=None, annotation=False, verbose=False, clobber=False):
     if annotation:
-        file_type = Annotations
+        file_type = Annotation
     else:
         file_type = Segmentation
 
@@ -41,15 +41,10 @@ def parse_options(args):
     parser = OptionParser(usage=usage, version=version,
                           description=description)
 
-    parser.add_option("--clobber", dest="clobber",
-                      default=False, action="store_true",
-                      help="Overwrite existing output files without warning")
-    parser.add_option("-q", "--quiet", action="store_false",
-                      dest="verbose", default=True,
-                      help="Do not print diagnostic messages.")
+    add_common_options(parser, ['clobber', 'quiet'])
     parser.add_option("--annotation", action="store_true",
                       dest="annotation", default=False,
-                      help="Read INFILE as a set of annotations, rather"
+                      help="Read INFILE as an annotation, rather"
                       " than as a segmentation (default).")
 
     (options, args) = parser.parse_args(args)
@@ -62,9 +57,7 @@ def parse_options(args):
 ## Command-line entry point
 def main(args=sys.argv[1:]):
     (options, args) = parse_options(args)
-    kwargs = {"verbose": options.verbose,
-              "clobber": options.clobber,
-              "annotation": options.annotation}
+    kwargs = dict(options.__dict__)
     preprocess(*args, **kwargs)
 
 if __name__ == "__main__":
